/*
Copyright (C) 2003-2004 Douglas Thain and the University of Wisconsin
Copyright (C) 2005- The University of Notre Dame
This software is distributed under the GNU General Public License.
See the file COPYING for details.
*/

#ifndef AUTH_KERBEROS_H
#define AUTH_KERBEROS_H

int auth_kerberos_register(void);

#endif
